@@ -1,17 +1,10 @@
-"""
-Copyright (C) 2021 Clariteia SL
+"""minos.common module."""
 
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
-
-__version__ = "0.1.11"
+__version__ = "0.1.12"
 
 from .configuration import (
     BROKER,
     COMMANDS,
-    CONTROLLER,
     DISCOVERY,
     EVENTS,
     QUEUE,
