@@ -31,7 +31,6 @@ from ..setup import (
     MinosSetup,
 )
 from .entries import (
-    RepositoryAction,
     RepositoryEntry,
 )
 
@@ -56,8 +55,11 @@ class MinosRepository(ABC, MinosSetup):
         """
         if not isinstance(entry, RepositoryEntry):
             entry = RepositoryEntry.from_aggregate_diff(entry)
+        from ..model import (
+            Action,
+        )
 
-        entry.action = RepositoryAction.CREATE
+        entry.action = Action.CREATE
         return await self._submit(entry)
 
     async def update(self, entry: Union[AggregateDiff, RepositoryEntry]) -> RepositoryEntry:
@@ -69,7 +71,11 @@ class MinosRepository(ABC, MinosSetup):
         if not isinstance(entry, RepositoryEntry):
             entry = RepositoryEntry.from_aggregate_diff(entry)
 
-        entry.action = RepositoryAction.UPDATE
+        from ..model import (
+            Action,
+        )
+
+        entry.action = Action.UPDATE
         return await self._submit(entry)
 
     async def delete(self, entry: Union[AggregateDiff, RepositoryEntry]) -> RepositoryEntry:
@@ -81,7 +87,11 @@ class MinosRepository(ABC, MinosSetup):
         if not isinstance(entry, RepositoryEntry):
             entry = RepositoryEntry.from_aggregate_diff(entry)
 
-        entry.action = RepositoryAction.DELETE
+        from ..model import (
+            Action,
+        )
+
+        entry.action = Action.DELETE
         return await self._submit(entry)
 
     @abstractmethod
@@ -107,6 +117,7 @@ class MinosRepository(ABC, MinosSetup):
         id_gt: Optional[int] = None,
         id_le: Optional[int] = None,
         id_ge: Optional[int] = None,
+        **kwargs
     ) -> AsyncIterator[RepositoryEntry]:
         """Perform a selection query of entries stored in to the repository.
 
@@ -137,6 +148,7 @@ class MinosRepository(ABC, MinosSetup):
             id_gt=id_gt,
             id_le=id_le,
             id_ge=id_ge,
+            **kwargs,
         )
         # noinspection PyTypeChecker
         async for entry in generator:
