@@ -13,12 +13,12 @@ from uuid import (
     UUID,
 )
 
-from ..constants import (
-    NULL_UUID,
-)
 from ..database import (
     PostgreSqlMinosDatabase,
 )
+from ..uuid import (
+    NULL_UUID,
+)
 from .abc import (
     MinosRepository,
 )
